class User:
    def __init__(self, id, email, firstName, lastName, countryCode, phone) -> None:
        self.id = id
        self.email = email
        self.firstName = firstName
        self.lastName = lastName
        self.countryCode = countryCode
        self.phone = phone